==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsFluent<A extends LoadBalancerSettingsFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsFluent() {
  }
  public LoadBalancerSettingsFluent(LoadBalancerSettings instance) {
    instance = (instance != null ? instance : new LoadBalancerSettings());

    if (instance != null) {
      this.withLbPolicy(instance.getLbPolicy());
      this.withLocalityLbSetting(instance.getLocalityLbSetting());
      this.withLbPolicy(instance.getLbPolicy());
      this.withLocalityLbSetting(instance.getLocalityLbSetting());
    }
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> lbPolicy;
  private LocalityLoadBalancerSettingBuilder localityLbSetting;
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy) {
    if (lbPolicy==null){ this.lbPolicy = null; _visitables.remove("lbPolicy"); return (A) this;}
    VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> builder = builder(lbPolicy); _visitables.get("lbPolicy").clear();_visitables.get("lbPolicy").add(builder);this.lbPolicy = builder;
    return (A) this;
  }
  public boolean hasLbPolicy() {
    return this.lbPolicy != null;
  }
  public LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy() {
    return new LoadBalancerSettingsSimpleLbPolicyNested(null);
  }
  public LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item) {
    return new LoadBalancerSettingsSimpleLbPolicyNested(item);
  }
  public LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy() {
    return new LoadBalancerSettingsConsistentHashLbPolicyNested(null);
  }
  public LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item) {
    return new LoadBalancerSettingsConsistentHashLbPolicyNested(item);
  }
  public LocalityLoadBalancerSetting buildLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting) {
    _visitables.get("localityLbSetting").remove(this.localityLbSetting);
    if (localityLbSetting!=null){ this.localityLbSetting= new LocalityLoadBalancerSettingBuilder(localityLbSetting); _visitables.get("localityLbSetting").add(this.localityLbSetting);} else { this.localityLbSetting = null; _visitables.get("localityLbSetting").remove(this.localityLbSetting); } return (A) this;
  }
  public boolean hasLocalityLbSetting() {
    return this.localityLbSetting != null;
  }
  public LocalityLbSettingNested<A> withNewLocalityLbSetting() {
    return new LocalityLbSettingNested(null);
  }
  public LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return new LocalityLbSettingNested(item);
  }
  public LocalityLbSettingNested<A> editLocalityLbSetting() {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(null));
  }
  public LocalityLbSettingNested<A> editOrNewLocalityLbSetting() {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(new LocalityLoadBalancerSettingBuilder().build()));
  }
  public LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsFluent that = (LoadBalancerSettingsFluent) o;
    if (!java.util.Objects.equals(lbPolicy, that.lbPolicy)) return false;

    if (!java.util.Objects.equals(localityLbSetting, that.localityLbSetting)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(lbPolicy,  localityLbSetting,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lbPolicy != null) { sb.append("lbPolicy:"); sb.append(lbPolicy + ","); }
    if (localityLbSetting != null) { sb.append("localityLbSetting:"); sb.append(localityLbSetting); }
    sb.append("}");
    return sb.toString();
  }
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsSimple": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsSimpleBuilder((LoadBalancerSettingsSimple) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHash": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashBuilder((LoadBalancerSettingsConsistentHash) item);
    }
 return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class LoadBalancerSettingsSimpleLbPolicyNested<N> extends LoadBalancerSettingsSimpleFluent<LoadBalancerSettingsSimpleLbPolicyNested<N>> implements Nested<N>{
    LoadBalancerSettingsSimpleLbPolicyNested(LoadBalancerSettingsSimple item) {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this, item);
    }
    LoadBalancerSettingsSimpleBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsSimpleLbPolicy() {
      return and();
    }
    
  }
  public class LoadBalancerSettingsConsistentHashLbPolicyNested<N> extends LoadBalancerSettingsConsistentHashFluent<LoadBalancerSettingsConsistentHashLbPolicyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLbPolicyNested(LoadBalancerSettingsConsistentHash item) {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLbPolicy(builder.build());
    }
    public N endLoadBalancerSettingsConsistentHashLbPolicy() {
      return and();
    }
    
  }
  public class LocalityLbSettingNested<N> extends LocalityLoadBalancerSettingFluent<LocalityLbSettingNested<N>> implements Nested<N>{
    LocalityLbSettingNested(LocalityLoadBalancerSetting item) {
      this.builder = new LocalityLoadBalancerSettingBuilder(this, item);
    }
    LocalityLoadBalancerSettingBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLocalityLbSetting(builder.build());
    }
    public N endLocalityLbSetting() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsFluent<A extends LoadBalancerSettingsFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsFluent() {
  }
  
  public LoadBalancerSettingsFluent(LoadBalancerSettings instance) {
    this.copyInstance(instance);
  }
  private VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> lbPolicy;
  private LocalityLoadBalancerSettingBuilder localityLbSetting;
  
  protected void copyInstance(LoadBalancerSettings instance) {
    instance = (instance != null ? instance : new LoadBalancerSettings());
  
    if (instance != null) {
        this.withLbPolicy(instance.getLbPolicy());
        this.withLocalityLbSetting(instance.getLocalityLbSetting());
        this.withLbPolicy(instance.getLbPolicy());
        this.withLocalityLbSetting(instance.getLocalityLbSetting());
      }
  }
  
  public IsLoadBalancerSettingsLbPolicy buildLbPolicy() {
    return this.lbPolicy!=null?this.lbPolicy.build():null;
  }
  
  public A withLbPolicy(IsLoadBalancerSettingsLbPolicy lbPolicy) {
    if (lbPolicy==null){ this.lbPolicy = null; _visitables.remove("lbPolicy"); return (A) this;}
    VisitableBuilder<? extends IsLoadBalancerSettingsLbPolicy,?> builder = builder(lbPolicy); _visitables.get("lbPolicy").clear();_visitables.get("lbPolicy").add(builder);this.lbPolicy = builder;
    return (A) this;
  }
  
  public boolean hasLbPolicy() {
    return this.lbPolicy != null;
  }
  
  public LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicy() {
    return new LoadBalancerSettingsSimpleLbPolicyNested(null);
  }
  
  public LoadBalancerSettingsSimpleLbPolicyNested<A> withNewLoadBalancerSettingsSimpleLbPolicyLike(LoadBalancerSettingsSimple item) {
    return new LoadBalancerSettingsSimpleLbPolicyNested(item);
  }
  
  public LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicy() {
    return new LoadBalancerSettingsConsistentHashLbPolicyNested(null);
  }
  
  public LoadBalancerSettingsConsistentHashLbPolicyNested<A> withNewLoadBalancerSettingsConsistentHashLbPolicyLike(LoadBalancerSettingsConsistentHash item) {
    return new LoadBalancerSettingsConsistentHashLbPolicyNested(item);
  }
  
  public LocalityLoadBalancerSetting buildLocalityLbSetting() {
    return this.localityLbSetting!=null ?this.localityLbSetting.build():null;
  }
  
  public A withLocalityLbSetting(LocalityLoadBalancerSetting localityLbSetting) {
    _visitables.get("localityLbSetting").remove(this.localityLbSetting);
    if (localityLbSetting!=null){ this.localityLbSetting= new LocalityLoadBalancerSettingBuilder(localityLbSetting); _visitables.get("localityLbSetting").add(this.localityLbSetting);} else { this.localityLbSetting = null; _visitables.get("localityLbSetting").remove(this.localityLbSetting); } return (A) this;
  }
  
  public boolean hasLocalityLbSetting() {
    return this.localityLbSetting != null;
  }
  
  public LocalityLbSettingNested<A> withNewLocalityLbSetting() {
    return new LocalityLbSettingNested(null);
  }
  
  public LocalityLbSettingNested<A> withNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return new LocalityLbSettingNested(item);
  }
  
  public LocalityLbSettingNested<A> editLocalityLbSetting() {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(null));
  }
  
  public LocalityLbSettingNested<A> editOrNewLocalityLbSetting() {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(new LocalityLoadBalancerSettingBuilder().build()));
  }
  
  public LocalityLbSettingNested<A> editOrNewLocalityLbSettingLike(LocalityLoadBalancerSetting item) {
    return withNewLocalityLbSettingLike(java.util.Optional.ofNullable(buildLocalityLbSetting()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsFluent that = (LoadBalancerSettingsFluent) o;
    if (!java.util.Objects.equals(lbPolicy, that.lbPolicy)) return false;
  
    if (!java.util.Objects.equals(localityLbSetting, that.localityLbSetting)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lbPolicy,  localityLbSetting,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lbPolicy != null) { sb.append("lbPolicy:"); sb.append(lbPolicy + ","); }
    if (localityLbSetting != null) { sb.append("localityLbSetting:"); sb.append(localityLbSetting); }
    sb.append("}");
    return sb.toString();
  }
  
  protected static <T>VisitableBuilder<T,?> builder(Object item) {
    switch (item.getClass().getName()) {
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsSimple": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsSimpleBuilder((LoadBalancerSettingsSimple) item);
    case "io.fabric8.istio.api.networking.v1alpha3."+"LoadBalancerSettingsConsistentHash": return (VisitableBuilder<T, ?>)new LoadBalancerSettingsConsistentHashBuilder((LoadBalancerSettingsConsistentHash) item);
    }
   return (VisitableBuilder<T, ?>)builderOf(item);
  }
  public class LoadBalancerSettingsSimpleLbPolicyNested<N> extends LoadBalancerSettingsSimpleFluent<LoadBalancerSettingsSimpleLbPolicyNested<N>> implements Nested<N>{
    LoadBalancerSettingsSimpleLbPolicyNested(LoadBalancerSettingsSimple item) {
      this.builder = new LoadBalancerSettingsSimpleBuilder(this, item);
    }
    LoadBalancerSettingsSimpleBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLbPolicy(builder.build());
    }
    
    public N endLoadBalancerSettingsSimpleLbPolicy() {
      return and();
    }
    
  
  }
  public class LoadBalancerSettingsConsistentHashLbPolicyNested<N> extends LoadBalancerSettingsConsistentHashFluent<LoadBalancerSettingsConsistentHashLbPolicyNested<N>> implements Nested<N>{
    LoadBalancerSettingsConsistentHashLbPolicyNested(LoadBalancerSettingsConsistentHash item) {
      this.builder = new LoadBalancerSettingsConsistentHashBuilder(this, item);
    }
    LoadBalancerSettingsConsistentHashBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLbPolicy(builder.build());
    }
    
    public N endLoadBalancerSettingsConsistentHashLbPolicy() {
      return and();
    }
    
  
  }
  public class LocalityLbSettingNested<N> extends LocalityLoadBalancerSettingFluent<LocalityLbSettingNested<N>> implements Nested<N>{
    LocalityLbSettingNested(LocalityLoadBalancerSetting item) {
      this.builder = new LocalityLoadBalancerSettingBuilder(this, item);
    }
    LocalityLoadBalancerSettingBuilder builder;
    
    public N and() {
      return (N) LoadBalancerSettingsFluent.this.withLocalityLbSetting(builder.build());
    }
    
    public N endLocalityLbSetting() {
      return and();
    }
    
  
  }

}
